import { QCheckBox, QWidget, QCheckBoxSignals } from "@nodegui/nodegui";
import { RNWidget } from "../config";
import { AbstractButtonProps } from "../AbstractComponents/RNAbstractButton";
/**
 * The CheckBox component provides ability to add and manipulate native button widgets. It is based on
 * [NodeGui's QCheckBox](https://docs.nodegui.org/docs/api/generated/classes/QCheckBox).
 * ## Example
 * ```javascript
 * import React from "react";
 * import { Renderer, CheckBox, Window } from "@nodegui/react-nodegui";
 * const App = () => {
 *   return (
 *     <Window>
 *       <CheckBox style={checkboxStyle} text={"Hello World"} checked={true} />
 *     </Window>
 *   );
 * };
 * const checkboxStyle = `
 *   color: white;
 * `;
 * Renderer.render(<App />);
 *
 * ```
 */
export interface CheckBoxProps extends AbstractButtonProps<QCheckBoxSignals> {
    /**
     * This property holds whether the button is checked. [QCheckBox: setChecked](https://docs.nodegui.org/docs/api/generated/classes/QCheckBox/#checkboxsetcheckedcheck)
     */
    checked?: boolean;
}
/**
 * @ignore
 */
export declare class RNCheckBox extends QCheckBox implements RNWidget {
    setProps(newProps: CheckBoxProps, oldProps: CheckBoxProps): void;
    appendInitialChild(child: QWidget<any>): void;
    appendChild(child: QWidget<any>): void;
    insertBefore(child: QWidget<any>, beforeChild: QWidget<any>): void;
    removeChild(child: QWidget<any>): void;
    static tagName: string;
}
